@@ -96,7 +96,10 @@ class Samples(Sampling):
         return h2s
 
     def u(
-        self, h2: complex | np.ndarray, w: complex, e1: complex
+        self,
+        h2: complex | np.ndarray,
+        w: complex | np.ndarray,
+        e1: complex | np.ndarray,
     ) -> complex | np.ndarray:
         # val: complex | np.ndarray = 1j * np.sqrt(-e1 * w ** 2 + h2) * self.r
         val: complex | np.ndarray = (
@@ -106,7 +109,10 @@ class Samples(Sampling):
         return val
 
     def v(
-        self, h2: complex | np.ndarray, w: complex, e2: complex
+        self,
+        h2: complex | np.ndarray,
+        w: complex | np.ndarray,
+        e2: complex | np.ndarray,
     ) -> complex | np.ndarray:
         val: complex | np.ndarray = (
             (1 - 1j) * np.sqrt(0.5j * (-e2 * w ** 2 + h2)) * self.r
